@@ -40,7 +40,7 @@ plot.aum_diffs <- function
     ggplot2::geom_segment(ggplot2::aes(
       min.pred, value,
       xend=max.pred, yend=value,
-      color=variable, size=variable),
+      color=variable, linewidth=variable),
       data=err.tall)+
     ggplot2::geom_vline(ggplot2::aes(
       xintercept=pred),
@@ -242,6 +242,8 @@ aum_diffs_penalty <- structure(function
 ### plot.aum_diffs.
 }, ex=function(){
 
+  if(require("data.table"))setDTthreads(1L)#for CRAN check.
+
   ## Simple synthetic example with two changes in error function.
   simple.df <- data.frame(
     example=1L,
@@ -280,7 +282,7 @@ aum_diffs_penalty <- structure(function
       geom_segment(aes(
         -log(min.lambda), value,
         xend=-log(max.lambda), yend=value,
-        color=variable, size=variable),
+        color=variable, linewidth=variable),
         data=fn.not.zero.tall)+
       geom_point(aes(
         -log(min.lambda), value,
